aboutsummaryrefslogtreecommitdiffstats
path: root/integration_test
diff options
context:
space:
mode:
Diffstat (limited to 'integration_test')
-rw-r--r--integration_test/network.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/integration_test/network.go b/integration_test/network.go
index 735d48a..b58cbcd 100644
--- a/integration_test/network.go
+++ b/integration_test/network.go
@@ -32,8 +32,8 @@ func (n *Network) BroadcastVote(vote *types.Vote) {}
func (n *Network) BroadcastBlock(block *types.Block) {
}
-// BroadcastNotaryAck broadcasts notaryAck to all nodes in DEXON network.
-func (n *Network) BroadcastNotaryAck(notaryAck *types.NotaryAck) {
+// BroadcastWitnessAck broadcasts witnessAck to all nodes in DEXON network.
+func (n *Network) BroadcastWitnessAck(witnessAck *types.WitnessAck) {
}
// SendDKGPrivateShare sends PrivateShare to a DKG participant.